-- =============================================
-- SaveToDB Framework for MySQL
-- Version 7.19, March 12, 2018
--
-- This script upgrades SaveToDB Framework 5.x to SaveToDB Framework 7.19
--
-- Copyright 2013-2018 Gartle Technology Corporation
-- =============================================

CREATE OR REPLACE VIEW savetodb_dev.view_query_list
AS
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, CONCAT(i.ROUTINE_SCHEMA, '.', i.ROUTINE_NAME)) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, CONCAT(u.ROUTINE_SCHEMA, '.', u.ROUTINE_NAME)) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, CONCAT(d.ROUTINE_SCHEMA, '.', d.ROUTINE_NAME)) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.ROUTINE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM
    information_schema.tables t
    LEFT OUTER JOIN information_schema.routines i ON i.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND i.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_insert')
    LEFT OUTER JOIN information_schema.routines u ON u.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND u.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_update')
    LEFT OUTER JOIN information_schema.routines d ON d.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND d.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_delete')
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
WHERE
    NOT t.TABLE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema')
UNION
SELECT
    r.ROUTINE_SCHEMA AS TABLE_SCHEMA
    , r.ROUTINE_NAME AS TABLE_NAME
    , r.ROUTINE_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, CONCAT(i.ROUTINE_SCHEMA, '.', i.ROUTINE_NAME)) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, CONCAT(u.ROUTINE_SCHEMA, '.', u.ROUTINE_NAME)) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, CONCAT(d.ROUTINE_SCHEMA, '.', d.ROUTINE_NAME)) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.ROUTINE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM 
    information_schema.routines r
    LEFT OUTER JOIN information_schema.routines i ON i.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND i.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_insert')
    LEFT OUTER JOIN information_schema.routines u ON u.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND u.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_update')
    LEFT OUTER JOIN information_schema.routines d ON d.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND d.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_delete')
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    NOT r.ROUTINE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema')
    AND r.ROUTINE_TYPE = 'PROCEDURE'
    AND NOT (
        r.ROUTINE_NAME LIKE '%_insert'
        OR r.ROUTINE_NAME LIKE '%_update'
        OR r.ROUTINE_NAME LIKE '%_delete'
        OR r.ROUTINE_NAME LIKE '%_merge'
        OR r.ROUTINE_NAME LIKE '%_change'
    )
UNION
SELECT
    q.TABLE_SCHEMA
    , q.TABLE_NAME
    , q.TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    savetodb_dev.query_list q
    LEFT OUTER JOIN information_schema.tables t ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
    LEFT OUTER JOIN information_schema.routines r ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.TABLE_NAME IS NULL
    AND r.ROUTINE_NAME IS NULL
ORDER BY
    TABLE_SCHEMA
    , TABLE_NAME;

delete from `savetodb_dev`.`table_formats` where `TABLE_SCHEMA` = 'savetodb_dev' and `TABLE_NAME` = 'event_handlers';

insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'event_handlers', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="2000" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="42.14" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="64" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-32768" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="32767" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-32768" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.Formula2" value="32767" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

-- 7.19

delete from `savetodb_dev`.`table_formats` where `TABLE_SCHEMA` = 'savetodb_dev' and `TABLE_NAME` = 'parameter_values';

insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'parameter_values', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.parameter_values">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="15.29" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String" />
<column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="53" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$8" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$8" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$8" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$8" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Priority" value="6" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

ALTER TABLE `savetodb_dev`.`event_handlers` MODIFY COLUMN `HANDLER_NAME` VARCHAR(64);

INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

delete from `savetodb_dev`.`table_formats` where `TABLE_SCHEMA` = 'savetodb_dev' and `TABLE_NAME` = 'event_handlers';

insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'event_handlers', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="2000" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="42.14" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="64" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-32768" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="32767" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-32768" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.Formula2" value="32767" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
